from .AGIExtraParam import AGIExtraParam
from .AGIResponse import AGIResponse
from .DialogManager import DialogManager
from .DialogManagerFactory import DialogManagerFactory
from .PromptObject import PromptObject

__all__ = ["PromptObject","DialogManagerFactory","AGIExtraParam","DialogManager","AGIResponse"]


from yyAutoAiframework.client import BaseAIClient

"""
管理DialogManager 的工厂实现类
主要用于维护创建的dialogManager 的状态
"""
class DialogManagerFactory:
    # 定义dialogManage 的对象集合
    _dialog_managers = {}
    #定义是否可以初始化
    __is_can_initialize = False
    """
    不允许外部直接调用
    """
    def __init__(self, client: BaseAIClient):
        if DialogManagerFactory.__is_can_initialize :  # 内部使用标记，不允许外部程序直接实例化
            self._dm_map = {}
            self.client = client
        else:
            raise RuntimeError("Direct instantiation is not allowed. Use 'create_dm_factory' instead.")

    """
    获取DialogManager Factory 
    对于同一个client 只创建一个DialogManagerFactory
    """
    @staticmethod
    def create_dm_factory(client: BaseAIClient):
        if client in DialogManagerFactory._dialog_managers:
            return DialogManagerFactory._dialog_managers[client]
        else:
            DialogManagerFactory.__is_can_initialize = True
            dm_factory =  DialogManagerFactory(client)
            DialogManagerFactory._dialog_managers[client] = dm_factory
            DialogManagerFactory.__is_can_initialize = False
            return dm_factory


    """
    获取对话管理实例
    """
    def get_dialog_manager(self, session_id:str,system_prompt: str = None, assistant_prompt: str = None):
        from yyAutoAiframework.agi_common.DialogManager import DialogManager
        if session_id in self._dm_map:
            return self._dm_map[session_id]
        else:
            DialogManager.authorized_caller = "DialogManagerFactory"
            dm = DialogManager(self,session_id,system_prompt,assistant_prompt)
            self._dm_map[session_id] = dm
            DialogManager.authorized_caller = None
            return dm


class AGIToolFunction:
    def __init__(self, name, arguments):
        self.arguments = arguments
        self.name = name

    def set_arguments(self, arguments):
        self.arguments = arguments
        return self

    def to_dict(self):
        return {
            "name": self.name,
            "arguments": self.arguments,
        }


class AGIToolCall:
    def __init__(self, id: str, type: str, function: AGIToolFunction = None):
        self.id = id
        self.type = type
        self.function = function

    def set_function(self, function: AGIToolFunction):
        self.function = function
        return self

    def get_function(self):
        return self.function

    def to_dict(self):
        return {
            "id": self.id,
            "type": self.type,
            "function": self.function.to_dict() if self.function else None,
        }


class StreamResponse:
    def __init__(self, stream_content):
        self.stream_content = stream_content

    def set_stream_content(self, stream_content):
        self.stream_content = stream_content
        return self

    def to_dict(self):
        return {
            "stream_content": self.stream_content
        }


class AGIResponse:

    def __init__(self):
        self.content = None,
        self.tool_calls = None
        self.role = None
        self.stream_response = None

    def set_content(self, content):
        self.content = content
        return self

    def set_tool_calls(self, tool_calls: AGIToolCall):
        if isinstance(tool_calls, list):
            self.tool_calls = tool_calls  # 设置为列表
        else:
            self.tool_calls.append(tool_calls)  # 单个添加到列表
        return self

    def set_role(self, role):
        self.role = role
        return self

    def set_stream_response(self, stream_response: StreamResponse):
        if isinstance(stream_response, list):
            self.stream_response = stream_response  # 设置为列表
        else:
            self.stream_response.append(stream_response)  # 单个添加到列表
        return self

    def get_content(self):
        return self.content

    def get_tool_calls(self):
        return self.tool_calls

    def get_role(self):
        return self.role

    def get_stream_response(self):
        return self.stream_response

    def to_dict(self):
        return {
            "content": self.content,
            "tool_calls": [tool_call.to_dict() for tool_call in self.tool_calls] if self.tool_calls else None,
            "role": self.role,
            "stream_response": self.stream_response,
        }



import logging

from yyAutoAiframework.util.AGIUtil import AGIUtil
from yyAutoAiframework.vector_db import BaseVectorDb

# from sentence_transformers import CrossEncoder

logger = logging.getLogger(__name__)

class RagBotComponent:
    model = None
    def __init__(self, vector_db:BaseVectorDb, llm_api, n_results=2):
        self.vector_db = vector_db
        self.llm_api = llm_api
        self.n_results = n_results

    def chat(self, user_query):
        # 1. 检索
        # search_results = self.vector_db.search(user_query, self.n_results*2)
        # print("search_results:"+AGIUtil.format_json(search_results))
        # if not RagBotComponent.model:
        #     print("加载模型...")
        #     model = CrossEncoder('BAAI/bge-reranker-large', max_length=512,device='cuda' if torch.cuda.is_available() else 'cpu')  # 多语言，国产，模型较大
        #     RagBotComponent.model = model
        #     print("加载模型结束...")
        #
        # scores = RagBotComponent.model.predict([(user_query, doc)
        #                         for doc in search_results])
        # sorted_list = sorted(
        #     zip(scores, search_results), key=lambda x: x[0], reverse=True)
        #
        # sorted_search_results = [doc for _, doc in sorted_list[:self.n_results]]
        #
        # print("sorted_search_results:"+AGIUtil.format_json(sorted_search_results))

        search_results = self.vector_db.search(user_query, self.n_results)
        logger.info("search_results:" + AGIUtil.format_json(search_results))
        sorted_search_results = search_results
        # 2. 构建 Prompt
        prompt_template = """
                    你是一个问答机器人。
                    你的任务是根据下述给定的已知信息回答用户问题。

                    已知信息:
                    {context}

                    用户问：
                    {query}

                    如果已知信息不包含用户问题的答案，或者已知信息不足以回答用户的问题，请直接回复"我无法回答您的问题"。
                    请不要输出已知信息中不包含的信息或答案。
                    请用中文回答用户问题。
                    """

        prompt = AGIUtil.build_prompt(
            prompt_template, context=sorted_search_results, query=user_query)

        # 3. 调用 LLM
        logger.info("开始调用LLM:")
        response = self.llm_api(prompt)
        return response


import os

from volcenginesdkarkruntime import Ark

from yyAutoAiframework.client.OpenAIBaseClient import OpenAIBaseClient
from yyAutoAiframework.client.OpenAIClient import OpenAIClient

"""
OpenAI 客户端实现
"""
class ARKClient(OpenAIBaseClient):

    def __init__(self):
        # 加载 .env 文件中定义的环境变量
        super().__init__()
        # 初始化 OpenAI 客户端
        self.client = Ark(
            api_key=os.getenv("ARK_API_KEY"),
            base_url=os.getenv("ARK_BASE_URL"),
            timeout = 120,
            max_retries=2
        )
        # self.default_model = "ep-20250102000704-2krqj"
        self.default_model = "ep-20250102001510-985qv"
        self.default_parse_model = "ep-20250102000929-phnpm"
        self.default_fc_model = "ep-20250102001510-985qv"
        self.default_temperature = 0
        self.embedding_client = OpenAIClient()
        self.embedding_model = "text-embedding-3-large"

    """
    判断是否支持Client_parese 功能
    """
    def is_client_can_parse(self) -> bool:
        return False

    def get_embeddings(self,texts,  model:str=None, dimensions=None):
        if model is None:
            model = self.embedding_model
        return self.embedding_client.get_embeddings(texts, model, dimensions)


class PromptObject:
    def __init__(self, context, instruction, output_format, example):
        """
        初始化 PromptObject 对象
        :param context: 任务的上下文说明
        :param instruction: 具体的任务说明
        :param output_format: 输出格式的要求
        :param examples: 示例数据，用来辅助任务理解
        """
        self.context = context
        self.instruction = instruction
        self.output_format = output_format
        self.example = example



from openai import BaseModel

from yyAutoAiframework.agi_common.AGIExtraParam import AGIExtraParam
from yyAutoAiframework.agi_common.AGIResponse import *
from yyAutoAiframework.agi_common.PromptObject import PromptObject

"""
通用AI客户端接口类，用于定义不同AI平台（如OpenAI和通义千问）的统一接口
"""


class BaseAIClient:
    """
    获取AGI 返回的Message信息
    """

    def get_completion_response(self, messages, response_format: str = "text",
                                extra_param: AGIExtraParam = None) -> AGIResponse:
        raise NotImplementedError("chat_completion 方法需要子类实现")

    """
    获取 Stream 留的Message 信息
    """

    """
    定义基础UTIL 类
    """

    def get_parsed_response(self, messages, response_format: BaseModel,
                            extra_param: AGIExtraParam = None) -> AGIResponse:
        raise NotImplementedError("chat_completion 方法需要子类实现")

    """
    根据用户输入获取标准返回
    """

    def call_agi_by_stand_prompt(self, prompt_obj: PromptObject, response_format="text",
                                 extra_param: AGIExtraParam = None) -> AGIResponse:
        raise NotImplementedError("chat_completion 方法需要子类实现")

    """
    执行Prompt 的调用
    """

    def call_agi_single_msg(self, prompt: str, response_format: str = "text",
                            extra_param: AGIExtraParam = None) -> AGIResponse:
        raise NotImplementedError("chat_completion 方法需要子类实现")

    """
    执行Prompt 的调用
    """

    def call_agi_messages(self, messages: [], response_format: str = "text",
                          extra_param: AGIExtraParam = None) -> AGIResponse:
        raise NotImplementedError("chat_completion 方法需要子类实现")

    """
    执行Prompt 的调用
    """

    def get_append_response_message(self, response) -> dict:
        raise NotImplementedError("chat_completion 方法需要子类实现")

    """
    判断是否支持Client_parese 功能
    """

    def is_client_can_parse(self) -> bool:
        raise NotImplementedError("chat_completion 方法需要子类实现")





import os

from openai import OpenAI

from yyAutoAiframework.client.OpenAIBaseClient import OpenAIBaseClient
from yyAutoAiframework.client.OpenAIClient import OpenAIClient

"""
月之暗面客户端实现
代表产品：KIMI
"""
class MoonshotClient(OpenAIBaseClient):

    def __init__(self):
        # 加载 .env 文件中定义的环境变量
        super().__init__()
        # 初始化 OpenAI 客户端
        self.client = OpenAI(
            api_key=os.getenv("MOONSHOT_API_KEY"),
            base_url=os.getenv("MOONSHOT_BASE_URL")
        )  # 使用环境变量中的 OPENAI_API_KEY 和 OPENAI_BASE_URL
        self.default_model = "moonshot-v1-8k"
        self.default_parse_model = "moonshot-v1-32k"
        self.default_fc_model = "moonshot-v1-8k"
        self.default_temperature = 0
        self.embedding_client = self
        self.embedding_model = "text-embedding-3-large"

    """
    判断是否支持Client_parese 功能
    """
    def is_client_can_parse(self) -> bool:
        return False

    def get_embeddings(self,texts,  model:str=None, dimensions=None):
        if model is None:
            model = self.embedding_model
        return self.embedding_client.get_embeddings(texts, model, dimensions)


class AGIExtraParam:

    def __init__(self, client: "BaseAIClient"):
        self.temperature = client.default_temperature
        self.model = client.default_model
        self.parse_model = client.default_parse_model
        self.fc_model = client.default_fc_model
        self.tools = None
        self.stream = False

    def set_temperature(self, temperature: int):
        self.temperature = temperature
        return self

    def set_tools(self, tools: [dict, list[dict]]):
        self.tools = tools
        return self

    def set_model(self, model: str):
        self.model = model
        return self

    def set_parse_model(self, parse_model: str):
        self.parse_model = parse_model
        return self

    def set_stream(self, stream: bool):
        self.stream = stream
        return self

    """
    将对象的所有属性转换为字典表示。
    """

    def to_dict(self):
        return {
            "temperature": self.temperature,
            "model": self.model,
            "tools": self.tools,
            "stream": self.stream
        }



import io
import re

import pandas as pd
import pdfplumber
from PIL import Image
from pdfminer.converter import PDFPageAggregator
from pdfminer.high_level import extract_pages
from pdfminer.layout import LTTextContainer, LAParams, LTImage
from pdfminer.pdfinterp import PDFResourceManager, PDFPageInterpreter
from pdfminer.pdfpage import PDFPage


class FileExtractUtil:

    @staticmethod
    def extract_text_from_pdf_miner(filename, page_numbers=None, min_line_length=1):
        '''从 PDF 文件中（按指定页码）提取文字'''
        paragraphs = []
        full_text = ''
        # 提取全部文本
        for i, page_layout in enumerate(extract_pages(filename)):
            buffer = ''
            # 如果指定了页码范围，跳过范围外的页
            if page_numbers is not None and i not in page_numbers:
                continue
            for element in page_layout:
                # print("是否TextContainer:%s,是否是LTRect:%s" % (isinstance(element, LTTextContainer),isinstance(element, LTRect)))
                if isinstance(element, LTTextContainer) :
                    element_text = element.get_text().strip().replace('\n', '')
                    # print("element_text:" + element_text)
                    if len(element_text) >= min_line_length:
                        buffer += (' '+element_text) if not element_text.endswith('-') else element_text.strip('-')



            #将此页的数据加入集合中
            if buffer:
                paragraphs.append(buffer)

        #打印前4段
        # for para in paragraphs:
        #     print("pdf 解析："+para + "\n")

        return paragraphs

    @staticmethod
    def remove_table_from_text(text_str:str, tables):
        for table in tables:
            if (len(table[1:])>1 or len(table[1:]) ==1 and table[1:][0][0]!="") and table[0] is not None and table[-1] is not None:
                first_row = ' '.join([str(item) if item is not None else '' for item in table[0]])
                last_row = ' '.join([str(item) if item is not None else '' for item in table[-1]])
                if len(last_row) >20:
                    # 截取Last_row 的前10个字+Last_row 的后10个字
                    last_row_part1 = last_row[:10].strip()
                    last_row_part2 = last_row[-10:].strip()
                    # 从文本中移除表格内容
                    pattern = re.escape(first_row)+r"[\s\S]*?"+re.escape(last_row_part1)+r"[\s\S]*?"+re.escape(last_row_part2)+""
                    text_str = re.sub(pattern, '', text_str, flags=re.DOTALL)
                else:
                    # 从文本中移除表格内容
                    pattern = re.escape(first_row)+r"[\s\S]*?"+re.escape(last_row)
                    text_str = re.sub(pattern, '', text_str, flags=re.DOTALL)

            # 将表格数据转换为字符串
            # table_str = '\n'.join(['\t'.join(row) for table in tables for row in table]
        return text_str

    @staticmethod
    def extract_text_from_pdf_plumber(filename, page_numbers=None, min_line_length=1):
        paragraphs = []
        with pdfplumber.open(filename) as pdf:
            for page in pdf.pages:
                buffer = ''
                # 如果指定了页码范围，跳过范围外的页
                if page_numbers is not None and page.page_number not in page_numbers:
                    continue
                element_text = page.extract_text()  # 提取纯文本
                tables = page.extract_tables()  # 提取表格
                if len(element_text) >= min_line_length:
                    append_str = FileExtractUtil.remove_table_from_text(element_text, tables)
                    append_str = re.sub(r'[\t ]', '', append_str)
                    buffer += (' ' + append_str+ "\n") if not append_str.endswith('-') else append_str.strip('-')
                for table in tables:
                    if len(table[1:])>1 or len(table[1:]) ==1 and table[1:][0][0]!="":
                        df = pd.DataFrame(table[1:], columns=table[0])
                        table_text = df.to_string()
                        if len(table_text) >= min_line_length:
                            buffer += (' ' + table_text+ "\n") if not table_text.endswith('-') else table_text.strip('-')

                # 将此页的数据加入集合中
                if buffer:
                    paragraphs.append(buffer)
        # #打印前4段
        for para in paragraphs:
            print("pdf 解析4："+para + "\n")

        return paragraphs

    # @staticmethod
    # def extract_table_from_pdf(filename, page_numbers=None):
    #     tables = tabula.read_pdf(filename, pages="all")
    #     for df in tables:
    #         print(df)

    """
    暂时不使用
    """
    @staticmethod
    def extract_image_from_pdf(filename):
        '''从 PDF 文件中提取图像'''
        image_info = []
        resource_manager = PDFResourceManager()
        laparams = LAParams()
        device = PDFPageAggregator(resource_manager, laparams=laparams)
        interpreter = PDFPageInterpreter(resource_manager, device)

        with open(filename, 'rb') as fp:
            for page in PDFPage.get_pages(fp):
                interpreter.process_page(page)
                layout = device.get_result()
                for lt_obj in layout:
                    if isinstance(lt_obj, LTImage):
                        image_info.append({
                            'page_number': page.pageid,
                            'x0': lt_obj.x0,
                            'y0': lt_obj.y0,
                            'x1': lt_obj.x1,
                            'y1': lt_obj.y1,
                            'width': lt_obj.width,
                            'height': lt_obj.height,
                            'stream': lt_obj.stream
                        })

        return image_info


    """
    暂时不使用
    """
    @staticmethod
    def save_images_from_pdf(filename, output_folder):
        '''从 PDF 文件中提取图像并保存到指定文件夹'''
        import os
        if not os.path.exists(output_folder):
            os.makedirs(output_folder)

        images = FileExtractUtil.extract_image_from_pdf(filename)
        for i, image in enumerate(images):
            stream = image['stream']
            file_ext = stream.get_ext()
            if file_ext in ['.jpg', '.jpeg']:
                img = Image.open(io.BytesIO(stream.get_rawdata()))
                img.save(os.path.join(output_folder, f'image_{i+1}.jpg'))
            elif file_ext == '.png':
                img = Image.open(io.BytesIO(stream.get_rawdata()))
                img.save(os.path.join(output_folder, f'image_{i+1}.png'))
            # 可以添加更多文件格式的支持

        return images


import os

import httpx
import requests
from openai import OpenAI

from yyAutoAiframework.client.OpenAIBaseClient import OpenAIBaseClient


class OpenAIClient(OpenAIBaseClient):
    """
    OpenAI 客户端实现
    """
    def __init__(self):
        # 加载 .env 文件中定义的环境变量
        super().__init__()
        proxy_url = os.getenv("PROXY_URL")
        http_client = httpx.Client(proxy=proxy_url)
        # 让 openai 使用这个 httpx 客户端
        openai_client = OpenAI(http_client= http_client)

        self.client = openai_client  # 使用环境变量中的 OPENAI_API_KEY 和 OPENAI_BASE_URL
        # self.default_model = "gpt-4o-mini"
        self.default_model = "gpt-4o"
        self.default_parse_model = "gpt-4o-mini-2024-07-18"
        self.default_fc_model = "gpt-4o-mini"
        self.default_temperature = 0
        self.embedding_client = self
        self.embedding_model = "text-embedding-3-large"

    """
    判断是否支持Client_parese 功能
    """

    def is_client_can_parse(self) -> bool:
        return True

    def get_embeddings(self,texts,  model:str=None, dimensions=None):
        if model is None:
            model = self.embedding_model
        return super().get_embeddings(texts, model, dimensions)



import os

import requests
from qianfan import Qianfan

from yyAutoAiframework.client.BaseAIClient import *
from yyAutoAiframework.client.OpenAIClient import OpenAIClient


class QianFanClient(OpenAIClient):
    """
    OpenAI 客户端实现
    """
    def __init__(self):
        # 加载 .env 文件中定义的环境变量
        super().__init__()
        # 初始化 OpenAI 客户端
        self.client = Qianfan(
            access_key=os.getenv("QIANFAN_ACCESS_KEY"),
            secret_key=os.getenv("QIANFAN_SECRET_KEY")
        )
        self.default_model = "ernie-speed-128k"
        # self.default_parse_model = "ERNIE-4.0-8K"
        # self.default_fc_model = "ERNIE-4.0-8K"
        self.default_parse_model = "ernie-lite-8k"
        self.default_fc_model = "ernie-lite-8k"
        self.default_temperature = 0.01
        self.embedding_client = self
        self.embedding_model = "text-embedding-3-large"

    """
    获取 Stream 留的Message 信息
    """

    def _convert_stream_message(self,response):
        def update_tool_call(tool_call):
            """更新或初始化工具调用对象"""
            nonlocal tool_calls, current_tool_call_index, function_name, args, function_id, function_type
            if current_tool_call_index == -1:
                # 重置函数信息及工具调用索引
                function_name, args, function_id, function_type = "", "", "", ""
                current_tool_call_index = 0
                tool_calls.append(None)
            # 更新函数信息
            if not function_name:
                function_name = tool_call.function.name
            if not function_id:
                function_id = tool_call.id
            if not function_type:
                function_type = tool_call.type
            # 拼装参数
            return (args if args is not None else "") + \
                (tool_call.function.arguments if tool_call.function.arguments is not None else "")

        def initialize_tool_call_if_needed():
            """在需要时初始化工具调用对象"""
            if (
                    tool_calls[current_tool_call_index] is None
                    and function_id
                    and function_type
                    and function_name
            ):
                agi_tool_call = AGIToolCall(function_id, function_type)
                agi_tool_call.set_function(AGIToolFunction(function_name, args))
                tool_calls[current_tool_call_index] = agi_tool_call

            elif tool_calls[current_tool_call_index]:
                tool_calls[current_tool_call_index].get_function().set_arguments(args)

        def process_stream_response(delta_content):
            """处理流响应内容"""
            nonlocal concatenated_text
            concatenated_text += delta_content
            stream_response_list.append(StreamResponse(delta_content))

        concatenated_text, role = "", ""
        tool_calls = None
        function_name, args, function_id, function_type = "", "", "", ""
        current_tool_call_index = -1
        stream_response_list = []
        for msg in response:
            delta = msg.choices[0].delta
            if delta.tool_calls:
                # 初始化工具调用列表
                if tool_calls is None:
                    tool_calls = []
                args = update_tool_call(delta.tool_calls[0])
                initialize_tool_call_if_needed()
            elif delta.content:
                process_stream_response(delta.content)
            # if not role and delta.role:
            #     role = delta.role

        # 设置最终响应对象
        agi_response = AGIResponse().set_content(concatenated_text).set_role(role).set_stream_response(
            stream_response_list)
        if tool_calls:
            agi_response.set_tool_calls(tool_calls)

        return agi_response

    """
    判断是否支持Client_parese 功能
    """
    def is_client_can_parse(self) -> bool:
        return False


    def get_embeddings(self,texts,  model:str=None, dimensions=None):
        if model is None:
            model = self.embedding_model
        return self.embedding_client.get_embeddings(texts, model, dimensions)

    # def get_embeddings(self,texts,  model="text-embedding-ada-002", dimensions=None):
    #     access_token = self._get_access_token()
    #     print(access_token)
    #     url = "https://aip.baidubce.com/rpc/2.0/ai_custom/v1/wenxinworkshop/embeddings/bge_large_en?access_token=" + access_token
    #     payload = json.dumps({
    #         "input": texts
    #     })
    #     headers = {'Content-Type': 'application/json'}
    #
    #     response = requests.request(
    #         "POST", url, headers=headers, data=payload).json()
    #     data = response["data"]
    #     return [x["embedding"] for x in data]

    def _get_access_token(self):
        """
        使用 AK，SK 生成鉴权签名（Access Token）
        :return: access_token，或是None(如果错误)
        """
        url = "https://aip.baidubce.com/oauth/2.0/token"
        params = {
            "grant_type": "client_credentials",
            "client_id": os.getenv("QIANFAN_ACCESS_KEY"),
            "client_secret": os.getenv("QIANFAN_SECRET_KEY")
        }

        return str(requests.post(url, params=params).json().get("access_token"))


import os

import chromadb
from chromadb import Settings

from yyAutoAiframework.vector_db.BaseVectorDb import BaseVectorDb


class ChromaVectorDb(BaseVectorDb):
    __chroma_client = None
    def __init__(self, collection_name, embedding_fn):
        # 加载 .env 文件中定义的环境变量
        super().__init__()
        # 获取环境变量并提供默认值
        __host_value = os.getenv("CHROME_DB_HOST")
        __port_value = int(os.getenv("CHROME_DB_PORT"))

        # chroma_client = chromadb.Client(Settings(allow_reset=True))
        if ChromaVectorDb.__chroma_client is None:
            ChromaVectorDb.__chroma_client = chromadb.HttpClient(host= __host_value, port=__port_value,settings=Settings(allow_reset=False))

        # 创建一个 collection
        self.collection = ChromaVectorDb.__chroma_client.get_or_create_collection(
            name=collection_name)
        self.embedding_fn = embedding_fn
        self.client = ChromaVectorDb.__chroma_client

    def add_documents(self, file_name,documents):
        import hashlib
        # 创建md5对象
        md5_obj = hashlib.md5()
        # 更新对象的字符串
        md5_obj.update(file_name.encode('utf-8'))  # 将字符串编码为UTF-8字节串
        # 获取16进制表示的哈希值
        file_name_md5_hash = md5_obj.hexdigest()
        print("MD5加密结果：", file_name_md5_hash)
        '''向 collection 中添加文档与向量'''
        self.collection.add(
            embeddings=self.embedding_fn(documents),  # 每个文档的向量
            documents=documents,  # 文档的原文
            ids=[file_name_md5_hash+f"id{i}" for i in range(len(documents))]  # 每个文档的 id
        )

    def search(self, query, top_n=3):
        '''检索向量数据库'''
        results = self.collection.query(
            query_embeddings=self.embedding_fn([query]),
            n_results=top_n
        )
        # print(AGIUtil.format_json(results))
        return results['documents'][0]

    def delete_documents_by_ids(self, ids):
        '''删除向量数据库'''
        self.collection.delete(ids=ids)

    def get_documents_count(self):
        '''获取向量数据库'''
        return self.collection.count()

    def get_all_documents(self):
        '''获取向量数据库'''
        return self.collection.get()

    def get_documents_by_ids(self,ids):
        '''获取向量数据库'''
        return self.collection.get(ids)

    def delete_all_documents(self):
        '''获取向量数据库'''
        return self.client.delete_collection(name=self.collection.name)



import re

from dotenv import load_dotenv, find_dotenv
from nltk import sent_tokenize


class BaseVectorDb:
    def __init__(self):
        # 加载 .env 文件中定义的环境变量
        _ = load_dotenv(find_dotenv())

    def add_documents(self, documents):
         raise NotImplementedError("add_documents 方法需要子类实现")

    def search(self, query, top_n):
         raise NotImplementedError("search 方法需要子类实现")


    @staticmethod
    def split_text_zh(paragraphs, chunk_size=300, overlap_size=100):
        return BaseVectorDb.split_text(paragraphs, chunk_size, overlap_size,lang='zh')

    @staticmethod
    def overlap_text_zh(paragraphs, overlap_size=100):
        return BaseVectorDb.overlap_text(paragraphs, overlap_size,lang='zh')

    @staticmethod
    def overlap_text(paragraphs, overlap_size=100, lang='en'):

        chunks = []
        for index, paragraph in enumerate(paragraphs):
            chunk = paragraph
            prev_overlap_index = -1
            next_overlap_index = -1
            if index != 0:
                prev_overlap_index = index - 1
            if index != len(paragraphs) - 1:
                next_overlap_index = index + 1

            if prev_overlap_index != -1:
                prev_overlap_paragraph = paragraphs[prev_overlap_index]
                if lang == 'zh':
                    sentences = [s.strip() for s in BaseVectorDb.sent_tokenize_zh(prev_overlap_paragraph)]
                else:
                    sentences = [s.strip() for s in sent_tokenize(prev_overlap_paragraph)]

                if len(sentences) > 0:
                    i = len(sentences)-1
                    overlap = ''
                    while i >= 0:
                        if len(sentences[i]) + len(overlap) <= overlap_size:
                            overlap = sentences[i] + ' ' + overlap
                            i -= 1
                        else:
                            break
                    chunk = overlap+chunk


            if next_overlap_index != -1:
                next_overlap_paragraph = paragraphs[next_overlap_index]
                if lang == 'zh':
                    sentences = [s.strip() for s in BaseVectorDb.sent_tokenize_zh(next_overlap_paragraph)]
                else:
                    sentences = [s.strip() for s in sent_tokenize(next_overlap_paragraph)]

                if len(sentences) > 0:
                    i = 0
                    overlap = ''
                    while i < len(sentences):
                        if len(sentences[i]) + len(overlap) <= overlap_size:
                            overlap = overlap+ ' ' + sentences[i]
                            i+=1
                        else:
                            break

                    chunk = chunk+overlap

            chunks.append(chunk)

        return chunks

    @staticmethod
    def split_text(paragraphs, chunk_size=300, overlap_size=100,lang='en'):
        '''按指定 chunk_size 和 overlap_size 交叠割文本'''
        if lang == 'zh':
            sentences = [s.strip() for p in paragraphs for s in BaseVectorDb.sent_tokenize_zh(p)]
        else:
            sentences = [s.strip() for p in paragraphs for s in sent_tokenize(p)]
        chunks = []
        i = 0
        while i < len(sentences):
            chunk = sentences[i]
            overlap = ''
            prev_len = 0
            prev = i - 1
            # 向前计算重叠部分
            while prev >= 0 and len(sentences[prev]) + len(overlap) <= overlap_size:
                overlap = sentences[prev] + ' ' + overlap
                prev -= 1
            chunk = overlap + chunk
            next = i + 1
            # 向后计算当前chunk
            while next < len(sentences) and len(sentences[next]) + len(chunk) <= chunk_size:
                chunk = chunk + ' ' + sentences[next]
                next += 1
            chunks.append(chunk)
            i = next
        return chunks

    def sent_tokenize_zh(input_string):
        """按标点断句"""
        # 按标点切分
        sentences = re.split(r'(?<=[。！？；?!])', input_string)
        # 去掉空字符串
        return [sentence for sentence in sentences if sentence.strip()]


from .ARKClient import ARKClient
from .OpenAIClient import OpenAIClient
from .OpenAIBaseClient import OpenAIBaseClient
from .MoonshotClient import MoonshotClient
from .DeepSeekClient import DeepSeekClient
from .DashscopeClient import DashscopeClient
from .BaseAIClient import BaseAIClient
from .QianFanClient import QianFanClient

__all__ = ["OpenAIClient", "MoonshotClient", "DeepSeekClient", "DashscopeClient","ARKClient",
           "QianFanClient","BaseAIClient"]


from setuptools import setup, find_packages

setup(
    name="yyAutoAiframework",         # 包名（必须唯一，PyPI上不能重复）
    version="1.0.6",          # 版本号（每次更新需递增）
    author="zhangxianchao",
    author_email="342588666@qq.com",
    description="将各种模型的实现差异进行封装，以适配大多数的模型",
    # long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/zhangxcYouyou/ai_framework",  # 项目主页
    packages=find_packages(), # 自动发现包
    install_requires=[        # 依赖项（可选）
        "elasticsearch7>=7.17.12",
        "nltk>=3.9.1",
        "numpy>=2.2.4",
        "openai>=1.3.5",
        "pandas>=2.2.3",
        "pdfplumber>=0.11.6",
        "pydantic>=2.11.3",
        "python-dotenv>=1.1.0",
        "qianfan>=0.4.12.3",
        "requests>=2.32.3",
        "volcengine-python-sdk>=1.0.118",
        "chromadb>=0.7.6",  # 添加 chromadb 依赖
        "setuptools>=78.1.0"
    ],
    classifiers=[            # 分类标签（可选）
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",  # Python 版本要求
)


import json


class AGIUtil:

    # 一个辅助函数，只为演示方便，不必关注细节
    @staticmethod
    def format_json(data) -> str:

        def custom_serializer(obj):
            # 如果碰到特殊对象（如 ChatCompletionMessageToolCall），转为字符串或字典
            if hasattr(obj, "__dict__"):  # 尝试将对象转为字典
                return obj.__dict__
            else:
                return str(obj)  # 否则直接序列化为字符串

        """
        打印参数。如果参数是有结构的（如字典或列表），则以格式化的 JSON 形式打印；
        否则，直接打印该值。
        """
        if hasattr(data, 'model_dump_json'):
            data = json.loads(data.model_dump_json())

        if hasattr(data, 'to_dict'):
            data = data.to_dict()

        if (isinstance(data, (list, dict))):
            return (json.dumps(
                data,
                indent=4,
                ensure_ascii=False,
                default=custom_serializer  # 使用自定义的序列化器
            ))
        else:
            return data

    @staticmethod
    def build_prompt(prompt_template, **kwargs):
        '''将 Prompt 模板赋值'''
        inputs = {}
        for k, v in kwargs.items():
            if isinstance(v, list) and all(isinstance(elem, str) for elem in v):
                val = '\n\n'.join(v)
            else:
                val = v
            inputs[k] = val
        return prompt_template.format(**inputs)


import re

import nltk
import numpy as np
from nltk.corpus import stopwords
from nltk.stem import PorterStemmer
from nltk.tokenize import word_tokenize
from numpy import dot
from numpy.linalg import norm


class RagUtil:
    # 实验室平台已经内置
    nltk.download('punkt')  # 英文切词、词根、切句等方法
    nltk.download('stopwords')  # 英文停用词库
    nltk.download('punkt_tab')

    @staticmethod
    def to_keywords(input_string):
        '''（英文）文本只保留关键字'''
        # 使用正则表达式替换所有非字母数字的字符为空格
        no_symbols = re.sub(r'[^a-zA-Z0-9\s]', ' ', input_string)
        word_tokens = word_tokenize(no_symbols)
        # 加载停用词表
        stop_words = set(stopwords.words('english'))
        ps = PorterStemmer()
        # 去停用词，取词根
        filtered_sentence = [ps.stem(w)
                             for w in word_tokens if not w.lower() in stop_words]
        return ' '.join(filtered_sentence)
    @staticmethod
    def cos_sim(a, b):
        '''余弦距离 -- 越大越相似'''
        return dot(a, b) / (norm(a) * norm(b))
    @staticmethod
    def l2(a, b):
        '''欧氏距离 -- 越小越相似'''
        x = np.asarray(a) - np.asarray(b)
        return norm(x)


from typing import Type

from dotenv import load_dotenv, find_dotenv

from yyAutoAiframework.client.BaseAIClient import *
from yyAutoAiframework.util.AGIUtil import AGIUtil


class OpenAIBaseClient(BaseAIClient):
    """
    OpenAI 客户端实现
    """
    def __init__(self):
        # 加载 .env 文件中定义的环境变量
        _ = load_dotenv(find_dotenv())
        self.client = None

    """
    定义基础UTIL 类
    """

    """
    获取AGI 返回的Message信息
    """

    def get_completion_response(self, messages, response_format: [str, dict,Type[BaseModel]] = "text",
                                extra_param: AGIExtraParam = None) -> AGIResponse:
        response_format = response_format or "text"
        # 设置默认值
        if extra_param is None:
            extra_param = AGIExtraParam(self)

        if isinstance(response_format, str):
            response_format = {"type": response_format}
        #如果是有tools 信息，则代表要执行funtion_calling ，则使用Fc_model
        chat_model = extra_param.model
        if extra_param.tools:
            chat_model = extra_param.fc_model

        if response_format == "text" or response_format == "json_object" or isinstance(response_format, dict):
            response = self.client.chat.completions.create(
                model=chat_model,
                messages=messages,
                temperature=extra_param.temperature,  # 模型输出的随机性，0 表示随机性最小
                # 返回消息的格式，text 或 json_object
                response_format=response_format,
                tools=extra_param.tools,
                stream=extra_param.stream,
            )
            if extra_param.stream:
                return self._convert_stream_message(response)
            else:
                return self._convert_agi_response(response)

        elif response_format is not None and isinstance(response_format, type) and self.is_client_can_parse():
            response = self.client.beta.chat.completions.parse(
                model=chat_model,
                messages=messages,
                temperature=extra_param.temperature,
                response_format=response_format,
            )
            response_message = response.choices[0].message
            return (AGIResponse().set_content(
                (AGIUtil.format_json(response_message.parsed) if response_message.parsed is not None else None))
                    .set_tool_calls(response_message.tool_calls)
                    .set_role(response_message.role))
        else:
            raise Exception("response_format 不支持")


    """
    获取 completion 的Message 信息
    """
    @staticmethod
    def _convert_agi_response(response) -> AGIResponse:
        reponse_message = response.choices[0].message
        agi_response = AGIResponse().set_content(reponse_message.content).set_role(reponse_message.role)
        if reponse_message.tool_calls is not None:
            tool_calls = []
            for tool_call in reponse_message.tool_calls:
                agi_tool_call = AGIToolCall(tool_call.id, tool_call.type)
                agi_tool_call.set_function(AGIToolFunction(tool_call.function.name, tool_call.function.arguments))
                tool_calls.append(agi_tool_call)
            # 添加Function Call
            agi_response.set_tool_calls(tool_calls)
        return agi_response

    """
    获取Stream 流对应的Message
    """
    def _convert_stream_message(self,response) -> AGIResponse:
        def update_tool_call(tool_call):
            """更新或初始化工具调用对象"""
            nonlocal tool_calls, current_tool_call_index, function_name, args, function_id, function_type
            if tool_call.index != current_tool_call_index:
                # 重置函数信息及工具调用索引
                function_name, args, function_id, function_type = "", "", "", ""
                current_tool_call_index = tool_call.index
                tool_calls.append(None)
            # 更新函数信息
            if not function_name:
                function_name = tool_call.function.name
            if not function_id:
                function_id = tool_call.id
            if not function_type:
                function_type = tool_call.type
            # 拼装参数
            return (args if args is not None else "") + \
                (tool_call.function.arguments if tool_call.function.arguments is not None else "")

        def initialize_tool_call_if_needed():
            """在需要时初始化工具调用对象"""
            if (
                    tool_calls[current_tool_call_index] is None
                    and function_id
                    and function_type
                    and function_name
            ):
                agi_tool_call = AGIToolCall(function_id, function_type)
                agi_tool_call.set_function(AGIToolFunction(function_name, args))
                tool_calls[current_tool_call_index] = agi_tool_call

            elif tool_calls[current_tool_call_index]:
                tool_calls[current_tool_call_index].get_function().set_arguments(args)

        def process_stream_response(delta_content):
            """处理流响应内容"""
            nonlocal concatenated_text
            concatenated_text += delta_content
            stream_response_list.append(StreamResponse(delta_content))

        concatenated_text, role = "", ""
        tool_calls = None
        function_name, args, function_id, function_type = "", "", "", ""
        current_tool_call_index = -1
        stream_response_list = []

        for msg in response:
            delta = msg.choices[0].delta
            if delta.tool_calls:
                # 初始化工具调用列表
                if tool_calls is None:
                    tool_calls = []
                args = update_tool_call(delta.tool_calls[0])
                initialize_tool_call_if_needed()
            elif delta.content:
                process_stream_response(delta.content)
            if not role and delta.role:
                role = delta.role

        # 设置最终响应对象
        agi_response = AGIResponse().set_content(concatenated_text).set_role(role).set_stream_response(
            stream_response_list)
        if tool_calls:
            agi_response.set_tool_calls(tool_calls)

        return agi_response

    """
    根据用户输入获取标准返回
    """

    def call_agi_by_stand_prompt(self, prompt_obj: PromptObject, response_format="text",
                                 extra_param: AGIExtraParam = None) -> AGIResponse:
        response_format = response_format or "text"
        prompt_template = f"""
        # 目标
        {prompt_obj.instruction}
        # 输出格式
        {prompt_obj.output_format}
        # 对话上下文
        {prompt_obj.context}
        """

        if prompt_obj.example is not None and prompt_obj.example != "":
            prompt_template = prompt_template + f"""
        # 举例
        {prompt_obj.example}
            """
        # print(prompt_template)
        # 执行调用
        return self.call_agi_single_msg(prompt_template, response_format, extra_param)

    """
    执行Prompt 的调用
    """

    def call_agi_single_msg(self, prompt: str, response_format: [str, dict,Type[BaseModel]] = "text",
                            extra_param: AGIExtraParam = None) -> AGIResponse:
        messages = [{"role": "user", "content": prompt}]  # 将 prompt 作为用户输入
        response = self.call_agi_messages(messages, response_format, extra_param)
        return response

    """
    执行Prompt 的调用
    """

    def call_agi_messages(self, messages: [], response_format: [str, dict,Type[BaseModel]] = "text",
                          extra_param: AGIExtraParam = None) -> AGIResponse:

        return self.get_completion_response(messages, response_format=response_format, extra_param=extra_param)

    """
    拼接Response 的信息，加入对话的上下文中
    """

    def get_append_response_message(self, response) -> [dict]:
        append_message = []
        # 将当前用户输入和系统回复维护入chatgpt的session
        if response.get_content():
            append_message.append({"role": response.get_role(), "content": response.get_content()})

        if response.get_tool_calls():
            append_message.append({"role": response.get_role(),
                                   "tool_calls": [self.to_tool_call_dict(tool_call) for tool_call in
                                                  response.get_tool_calls()]})

        return append_message

    """
    将AGI TOOL Call 转化成 OpenAPI 支持的格式
    """

    def to_tool_call_dict(self, tool_call: AGIToolCall) -> dict:
        return {
            "id": tool_call.id,
            "type": tool_call.type,
            "function": {"name": tool_call.function.name,
                         "arguments": tool_call.function.arguments} if tool_call.function else None
        }

    def get_embeddings(self,texts,  model:str=None, dimensions=None):
        '''封装 OpenAI 的 Embedding 模型接口'''
        if model == "text-embedding-ada-002":
            dimensions = None
        if dimensions:
            data = self.client.embeddings.create(
                input=texts, model=model, dimensions=dimensions).data
        else:
            data = self.client.embeddings.create(input=texts, model=model).data
        return [x.embedding for x in data]




import os
import time
import warnings

from elasticsearch7 import Elasticsearch, helpers

from yyAutoAiframework.util.RagUtil import RagUtil
from yyAutoAiframework.vector_db.BaseVectorDb import BaseVectorDb


class ESVectorDb(BaseVectorDb):
    def __init__(self, collection_name, embedding_fn):
        # 加载 .env 文件中定义的环境变量
        super().__init__()
        # 引入配置文件
        ELASTICSEARCH_BASE_URL = os.getenv('ELASTICSEARCH_BASE_URL')
        ELASTICSEARCH_PASSWORD = os.getenv('ELASTICSEARCH_PASSWORD')
        ELASTICSEARCH_NAME = os.getenv('ELASTICSEARCH_NAME')
        # 初始化 OpenAI 客户端
        # tips: 如果想在本地运行，请在下面一行 print(ELASTICSEARCH_BASE_URL) 获取真实的配置

        # 1. 创建Elasticsearch连接
        es = Elasticsearch(
            hosts=[ELASTICSEARCH_BASE_URL],  # 服务地址与端口
            http_auth=(ELASTICSEARCH_NAME, ELASTICSEARCH_PASSWORD),  # 用户名，密码
        )
        self.embedding_fn = embedding_fn

        # 3. 如果索引已存在，删除它（仅供演示，实际应用时不需要这步）
        if not es.indices.exists(index=collection_name) :
            es.indices.create(index=collection_name)

        self.instance = es
        self.collection = collection_name
        warnings.simplefilter("ignore")  # 屏蔽 ES 的一些Warnings

    """
    初始化ES 数据
    """
    def add_documents(self,documents):
        es = self.instance
        # 5. 灌库指令
        actions = [
            {
                "_index": self.collection,
                "_source": {
                    "keywords": self.embedding_fn(para),
                    "text": para
                }
            }
            for para in documents
        ]
        helpers.bulk(es, actions)
        time.sleep(2)


    """
    执行ES 查询
    """
    def search(self,query_string,top_n=3):
        es = self.instance
        # ES 的查询语言
        search_query = {
            "match": {
                "keywords": RagUtil.to_keywords(query_string)
            }
        }
        res = es.search(index=self.collection, query=search_query, size=top_n)
        print(res)
        results =  [hit["_source"]["text"] for hit in res["hits"]["hits"]]
        for r in results:
            print("ES 查询结果："+r + "\n")
        return results


import json
from typing import Type

from pydantic import BaseModel

from yyAutoAiframework.agi_common.AGIExtraParam import AGIExtraParam
from yyAutoAiframework.agi_common.AGIResponse import AGIResponse
from yyAutoAiframework.agi_common.DialogManagerFactory import DialogManagerFactory
from yyAutoAiframework.util.AGIUtil import AGIUtil


class DialogManager:
    authorized_caller = None

    def __init__(self, dm_factory: DialogManagerFactory,session_id: str, system_prompt: str = None, assistant_prompt: str = None):
        # 验证合法调用者
        if DialogManager.authorized_caller != "DialogManagerFactory":
            raise PermissionError("DialogManager can only be initialized by DialogManagerFactory!")
        self.state = {}
        self.session = []
        self.dm_factory = dm_factory
        self.session_id = session_id
        if system_prompt is not None:
            self.session.append({
                "role": "system",
                "content": system_prompt
            })
        if assistant_prompt is not None:
            self.session.append({
                "role": "assistant",
                "content": assistant_prompt
            })

    """
    将用户输入的信息调用AGI
    """

    def call_agi_user_message(self, user_input, response_format: [str, dict] = "text",
                              extra_param: AGIExtraParam = None) -> AGIResponse:
        self.session.append({"role": "user", "content": user_input})
        # 执行调用
        return self.call_agi_message(response_format, extra_param)

    """
    将Function Calling 生成的消息 调用AGI
    """

    def call_agi_tool_message(self, tool_call, tool_input: str, response_format: [str, dict] = "text",
                              extra_param: AGIExtraParam = None) -> AGIResponse:
        self.session.append({"tool_call_id": tool_call.id,
                             "name": tool_call.function.name,
                             "role": "tool",
                             "content": tool_input
                             })
        # 执行调用
        return self.call_agi_message(response_format, extra_param)

    """
    执行对话框的agi 调用
    """

    def call_agi_message(self, response_format: [str, dict] = "text", extra_param: AGIExtraParam = None) -> AGIResponse:
        response = self.dm_factory.client.call_agi_messages(self.session, response_format, extra_param)
        # 将当前用户输入和系统回复维护入chatgpt的session
        self.session.extend(self.dm_factory.client.get_append_response_message(response))
        return response

    """
    将用户输入的信息调用AGI,以生成对应信息的解析
    """

    def call_agi_user_parse(self, user_input, response_format: [Type[BaseModel], dict],
                            extra_param: AGIExtraParam = None) -> AGIResponse:
        self.session.append({"role": "user", "content": user_input})
        # 执行调用
        return self.call_agi_parse(response_format, extra_param)

    """
    执行对话框的agi 调用，用于生成信息解析
    """

    def call_agi_parse(self, response_format: [Type[BaseModel], dict],
                       extra_param: AGIExtraParam = None) -> AGIResponse:
        response = self.dm_factory.client.get_parsed_response(self.session, response_format, extra_param)
        # 将当前用户输入和系统回复维护入chatgpt的session
        self.session.extend(self.dm_factory.client.get_append_response_message(response))
        return response

    """
    拼接Tool Call 的message 
    """

    def append_agi_tool_message(self, tool_call, tool_input: str):
        self.session.append({"tool_call_id": tool_call.id,
                             "name": tool_call.function.name,
                             "role": "tool",
                             "content": tool_input
                             })

    """
    输出dialogManager 相关的Message 信息
    """

    def print_dm_messages(self):
        print(AGIUtil.format_json(self.session))

    """
    执行Tool Call 的逻辑
    """
    def exec_tool_calls(self,response:AGIResponse,tool_callback,extra_param: AGIExtraParam = None):
        last_function_name = ""
        # 如果返回的是函数调用结果，则打印出来
        while response.get_tool_calls() is not None:
            for tool_call in response.get_tool_calls():
                args = json.loads(tool_call.function.arguments)
                # 解决重复调用问题，目前只发现 Deepseek 有这个问题
                if last_function_name != tool_call.function.name:
                    # print("函数参数展开：%s %s" % (tool_call.function.name,AGIUtil.format_json(args)))
                    result = ""
                    # 使用回调函数执行逻辑
                    if callable(tool_callback):
                        try:
                            result = tool_callback(tool_call.function.name, args)
                        except Exception as e:
                            print(f"执行 Tool 回调发生异常: {str(e)}")
                            result = {"error": str(e)}

                        # print("%s=====函数返回=====：%s " % (tool_call.function.name,AGIUtil.format_json(result)))
                        self.append_agi_tool_message(tool_call, str(result))
                        last_function_name = tool_call.function.name

            # 执行调用
            # self.print_dm_messages()
            response = self.call_agi_message(extra_param=extra_param)

        # self.print_dm_messages()
        #返回Response
        return response


import os

from openai import OpenAI
from yyAutoAiframework.agi_common.AGIResponse import *
from yyAutoAiframework.client.OpenAIBaseClient import OpenAIBaseClient
from yyAutoAiframework.client.OpenAIClient import OpenAIClient


class DeepSeekClient(OpenAIBaseClient):
    """
    OpenAI 客户端实现
    """
    def __init__(self):
        # 加载 .env 文件中定义的环境变量
        super().__init__()
        # 初始化 OpenAI 客户端
        self.client = OpenAI(
            api_key=os.getenv("DEEPSEEK_API_KEY"),
            base_url=os.getenv("DEEPSEEK_BASE_URL")
        )  # 使用环境变量中的 OPENAI_API_KEY 和 OPENAI_BASE_URL
        # self.default_model = "deepseek-r1:70b"
        # self.default_parse_model = "deepseek-r1:70b"
        # self.default_fc_model = "deepseek-r1:70b"
        self.default_model = "deepseek-chat"
        self.default_parse_model = "deepseek-chat"
        self.default_fc_model = "deepseek-chat"
        self.default_temperature = 0
        self.embedding_client = self
        self.embedding_model = "text-embedding-3-large"

    """
    判断是否支持Client_parese 功能
    """
    def is_client_can_parse(self) -> bool:
        return False


    def get_embeddings(self,texts,  model:str=None, dimensions=None):
        if model is None:
            model = self.embedding_model
        return self.embedding_client.get_embeddings(texts, model, dimensions)


    @staticmethod
    def _convert_agi_response(response) -> AGIResponse:
        response_message = response.choices[0].message
        agi_response = AGIResponse().set_content(response_message.content.split("</think>")[-1]).set_role(response_message.role)
        if response_message.tool_calls is not None:
            tool_calls = []
            for tool_call in response_message.tool_calls:
                agi_tool_call = AGIToolCall(tool_call.id, tool_call.type)
                agi_tool_call.set_function(AGIToolFunction(tool_call.function.name, tool_call.function.arguments))
                tool_calls.append(agi_tool_call)
            # 添加Function Call
            agi_response.set_tool_calls(tool_calls)
        return agi_response